@@ -131,10 +131,6 @@ oesg <- function(y, modelA="MNN", modelB="MNN", persistenceA=NULL, persistenceB=
 # Start measuring the time of calculations
     startTime <- Sys.time();
 
-    ##### Check if data was used instead of y. Remove by 2.6.0 #####
-    y <- depricator(y, list(...), "data");
-    interval <- depricator(interval, list(...), "intervals");
-
     ##### Preparations #####
     occurrence <- "g";
 
@@ -365,7 +361,7 @@ oesg <- function(y, modelA="MNN", modelB="MNN", persistenceA=NULL, persistenceB=
 
         # Persistence vector. The initials are set here!
         if(persistenceEstimate){
-            vecg <- matrix(0.01, nComponentsAll, 1);
+            vecg <- matrix(0.1, nComponentsAll, 1);
         }
         else{
             vecg <- matrix(persistence, nComponentsAll, 1);
